import { shallowMount } from "@vue/test-utils";
import StatusMessage from "../../../src/components/LayoutBuilderStatusMessage.vue";

describe("StatusMessage.vue", () => {
  it("typeClass returns a computed string including the given type", () => {
    const type = "type";
    const wrapper = shallowMount(StatusMessage, {
      propsData: {
        message: "foo",
        type
      }
    });

    expect(wrapper.vm.typeClass).toBe(`is-${type}`);
  });

  describe("triggering 'animationend'", () => {
    const wrapper = shallowMount(StatusMessage, {
      propsData: {
        message: "foo",
        type: "type"
      }
    });
    const stub = jest.fn();
    wrapper.setMethods({ onAnimationEnd: stub });

    it("calls onAnimationEnd()", () => {
      wrapper.element.dispatchEvent(new Event("animationend"));
      expect(stub).toHaveBeenCalled();
    });
  });

  describe("onAnimationEnd()", () => {
    const wrapper = shallowMount(StatusMessage, {
      propsData: {
        message: "foo",
        type: ""
      }
    });

    it("emits 'animation-end'", () => {
      wrapper.vm.onAnimationEnd();
      expect(wrapper.emitted("animation-end")).toBeTruthy();
    });
  });
});
